Module errors

Module errors 

Top-level error type for the CLI and the SDK→user message mapping.

Enums

CliError

Functions

exit_code_for
Map a CLI error to its process exit code.
render
Renders the error to a human-friendly message using the real process argv for did-you-mean suggestions. Use render_with_argv from tests where the simulated argv differs from the process argv.
render_with_argv
Like render but uses the supplied argv values for did-you-mean lookup.